<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: Pat2rdf.xsl,v 1.23 2009/11/30 03:42:28 eric Exp $ -->
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:in="http://indivo.org/vocab/xml/documents#"
    version="2.0"
    xmlns="tag:eric@w3.org:2009/tmo/translator#"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    xmlns:foaf="http://xmlns.com/foaf/0.1/"
    xmlns:trans="tag:eric@w3.org:2009/tmo/translator#"  
    xmlns:indivo="http://indivo.org/vocab/xml/documents#"
    xmlns:xsd="http://www.w3.org/2001/XMLSchema#"
    xmlns:cpr="http://purl.org/cpr/0.75#"
    xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
    xmlns:ro="http://www.obofoundry.org/ro/ro.owl#"
    xmlns:skos="http://www.w3.org/2004/02/skos/core#"
    xmlns:dct="http://purl.org/dc/terms/"
    >

<xsl:output method="xml" indent='yes' encoding='utf-8'
	    omit-xml-declaration="yes"	    
	    media-type="text/turtle" version="1.0"/>

<xsl:template match="in:Envelope">
  <rdf:RDF>
    <cpr:patient-record rdf:about="" />
    <rdf:Descrption rdf:nodeID="patient">
      <cpr:subjectOfDescription rdf:resource=""/>
    </rdf:Descrption>
    <xsl:apply-templates select="in:CurrentStatus"/>
    <xsl:apply-templates select="in:Encounter"/>
  </rdf:RDF>
</xsl:template>

<xsl:template match="in:CurrentStatus">
  <xsl:apply-templates select="in:PatientID"/>
  <xsl:apply-templates select="in:Contact"/>
  <xsl:apply-templates select="in:PrimaryCarePhysician"/>
  <xsl:apply-templates select="in:Demographics"/>
  <xsl:apply-templates select="in:Prescriptions"/>
  <xsl:apply-templates select="in:Conditions"/>
  <!-- xsl:apply-templates select="in:Procedures"/ -->
  <!-- xsl:apply-templates select="in:Allergies"/ -->
  <!-- xsl:apply-templates select="in:Immunizations"/ -->
  <!-- xsl:apply-templates select="in:lifestyle"/ -->
  <!-- xsl:apply-templates select="in:familyHistory"/ -->
</xsl:template>

<xsl:template match="in:PatientID">
  <rdf:Description rdf:nodeID="patient">
    <cpr:patientID><xsl:value-of select="."/></cpr:patientID>
  </rdf:Description>
</xsl:template>

<xsl:template match="in:Contact">
  <xsl:call-template name="contact">
    <xsl:with-param name="subject" select="'patient'"/>
    <xsl:with-param name="type" select="'cpr:patient'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="in:PrimaryCarePhysician">
  <rdf:Description rdf:about="tag:eric@w3.org:2009/tmo/translator#PrimaryCarePhysician">
    <rdfs:subClassOf rdf:resource="http://purl.org/cpr/0.75#physician"/><xsl:comment>ont</xsl:comment>
  </rdf:Description>
  <xsl:call-template name="contact">
    <xsl:with-param name="subject" select="'pricare'"/>
    <xsl:with-param name="type" select="'trans:PrimaryCarePhysician'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="in:Demographics">
  <rdf:Description rdf:nodeID="patient">
    <trans:demographics>
      <xsl:attribute name="indivo:dateOfBirth">
	<xsl:apply-templates mode="date" select="in:dateOfBirth"/>
      </xsl:attribute>
      <xsl:attribute name="indivo:gender">
	<xsl:value-of select="in:gender/text()"/>"
      </xsl:attribute>
    </trans:demographics>
  </rdf:Description>
</xsl:template>

<xsl:template name="contact">
  <xsl:param name="subject"/>
  <xsl:param name="type"/>
  <xsl:element name="{$type}">
    <xsl:attribute name="rdf:nodeID">
      <xsl:value-of select="$subject"/>
    </xsl:attribute>
    <xsl:apply-templates mode="contact"/>
  </xsl:element>
</xsl:template>

<xsl:template mode="contact" match="in:name">
  <xsl:apply-templates mode="contact" select="*"/>
</xsl:template>

<xsl:template mode="contact" match="in:fullName">
  <foaf:name><xsl:value-of select="text()"/></foaf:name>
</xsl:template>

<xsl:template mode="contact" match="in:givenName">
  <foaf:givenName><xsl:value-of select="text()"/></foaf:givenName>
</xsl:template>

<xsl:template mode="contact" match="in:familyName">
  <foaf:familyName><xsl:value-of select="text()"/></foaf:familyName>
</xsl:template>

<xsl:template mode="contact" match="in:email">
  <xsl:if test="text()">
    <foaf:mbox>
      <xsl:attribute name="rdf:resource">
	<xsl:value-of select="concat('mailto:', text())"/>
      </xsl:attribute>
    </foaf:mbox>
  </xsl:if>
</xsl:template>

<xsl:template mode="contact" match="*">
</xsl:template>

<xsl:template match="in:Prescriptions">
  <xsl:apply-templates select="in:Prescription"/>
</xsl:template>

<xsl:template match="in:Prescription">
  <cpr:substance-administration>
    <trans:prescribedTo rdf:nodeID="patient"/>
    <cpr:startsNoEarlierThan><xsl:apply-templates mode="date" select="in:medication/in:dateStarted"/></cpr:startsNoEarlierThan><!-- trans:dateStarted -->
    <xsl:if test="in:medication/in:dateStopped"> 
      <cpr:stopsNoEarlierThan><xsl:apply-templates mode="date" select="in:medication/in:dateStopped"/></cpr:stopsNoEarlierThan>
    </xsl:if>
    <ro:has_participant><cpr:medication>
      <trans:ndcCode><xsl:value-of select="concat('http://indivo.org/codes/ndc/', normalize-space(in:medication/in:name))"/></trans:ndcCode>
      <trans:genericName><xsl:value-of select="in:medication/in:genericName"/></trans:genericName>
    </cpr:medication></ro:has_participant>
  </cpr:substance-administration>
</xsl:template>

<xsl:template match="in:Conditions">
  <xsl:apply-templates select="in:Problem"/>
</xsl:template>

<xsl:template match="in:Problem">
  <rdf:Description rdf:nodeID="patient">
    <trans:hasCondition><rdf:Description><xsl:apply-templates mode="problem" select="*"/></rdf:Description></trans:hasCondition>
  </rdf:Description>
  <xsl:apply-templates mode="resources" select="in:name"/>
</xsl:template>

<xsl:template mode="problem" match="in:dateOnset">
  <cpr:startsNoLaterThan><xsl:apply-templates mode="date" select="."/></cpr:startsNoLaterThan>
</xsl:template>

<xsl:template mode="problem" match="in:name">
   <xsl:variable name="problemL"  select="text()"/>
   <xsl:variable name="problem"   select="lower-case(replace(replace(translate($problemL,' >.:@','_____'),$SQ2,''),$SQ,''))"/>
  <trans:diagnosedWith><xsl:attribute name="rdf:resource"><xsl:value-of select="concat('tag:eric@w3.org:2009/tmo/translator#', $problem)"/></xsl:attribute></trans:diagnosedWith>
  <trans:ICD9><xsl:value-of select="@value"/></trans:ICD9>
</xsl:template>

<xsl:template mode="resources" match="in:name">
   <xsl:variable name="problemL"  select="text()"/>
   <xsl:variable name="problem"   select="lower-case(replace(replace(translate($problemL,' >.:@','_____'),$SQ2,''),$SQ,''))"/>
   <xsl:element name="{$problem}">
     <dct:identifier><xsl:value-of select="$problemL"/></dct:identifier>
   </xsl:element>
</xsl:template>

<xsl:template mode="problem" match="*">
<xsl:comment>unmatched <xsl:value-of select="name()"/></xsl:comment>
</xsl:template>

<xsl:template match="in:Encounter">
  <trans:Encounter>
    <trans:patient rdf:nodeID="patient"/>
    <trans:dateOfEncounter><xsl:apply-templates mode="date" select="in:Date"/></trans:dateOfEncounter>
    <xsl:apply-templates select="in:WorkingDiagnosis/in:PreliminaryDiagnosis"/>
    <trans:reportedSymptoms><xsl:value-of select="in:ReportedSymptoms/text()"/></trans:reportedSymptoms>
<xsl:apply-templates select="in:LabTests/in:Test"/>    
  </trans:Encounter>
<xsl:apply-templates select="*//in:SNPresult" mode="relate-variants"/>    
</xsl:template>

<xsl:template match="in:PreliminaryDiagnosis">
    <trans:workingDiagnosis><xsl:value-of select="in:DiagnosisDescription/text()"/></trans:workingDiagnosis>
</xsl:template>

<xsl:template match="in:Test">
  <trans:test><rdf:Description>
    <xsl:comment>indivo:dateMeasured <xsl:apply-templates mode="date" select="in:dateMeasured"/> ;</xsl:comment>
    <trans:testName><xsl:value-of select="in:name/text()"/></trans:testName>
    <xsl:apply-templates select="in:result"/><xsl:apply-templates select="in:SNPresult"/>
  </rdf:Description></trans:test>
</xsl:template>

<xsl:template match="in:Test[in:SNPresult]">
  <!-- @@ got invalid QName {}  trans:test><xsl:element name="{replace(replace(in:name/text(),' ','_'),$SQ,'')}" -->
  <trans:test><rdf:Description>
    <rdf:type><xsl:attribute name="rdf:resource"><xsl:value-of select="replace(replace(in:name/text(),' ','_'),$SQ,'')"/></xsl:attribute></rdf:type>
    <xsl:comment>indivo:dateMeasured <xsl:apply-templates mode="date" select="in:dateMeasured"/> ;</xsl:comment>
    <xsl:apply-templates select="in:result"/>
    <xsl:apply-templates select="in:SNPresult"/>
  </rdf:Description></trans:test>
</xsl:template>
<xsl:variable name="SQ">
<xsl:text>'</xsl:text>
</xsl:variable>
<xsl:variable name="SQ2">
<xsl:text>’</xsl:text>
</xsl:variable>
<xsl:variable name="DQ">
<xsl:text>"</xsl:text>
</xsl:variable>
<xsl:variable name="NL">
<xsl:text>
</xsl:text>
</xsl:variable>

<xsl:template match="in:result">
<xsl:comment>@@not done ;</xsl:comment>
</xsl:template>

<!-- Replaced by lebot Jan 2011 
xsl:template match="in:SNPresult">
       trans:result [
           trans:variant_Synonyms "<xsl:value-of select="in:LabTest/in:variant_Synonyms/text()"/>" ;
       ] ;
</xsl:template-->

<xsl:template match="in:SNPresult">
   <xsl:variable name="variant-synonyms" select="tokenize(in:LabTest/in:variant_Synonyms/text(),'[,;]')"/>
   <xsl:variable name="primary-synonymL"  select="normalize-space($variant-synonyms[1])"/>
   <xsl:variable name="primary-synonym"   select="concat('variant_',translate($primary-synonymL,'>.:@','____'))"/>
   <trans:result><SNPResult>
     <trans:feature><xsl:attribute name="rdf:resource"><xsl:value-of select="concat('tag:eric@w3.org:2009/tmo/translator#', $primary-synonym)"/></xsl:attribute></trans:feature>
     <trans:present rdf:datatype="http://www.w3.org/2001/XMLSchema#boolean">true</trans:present>
   </SNPResult></trans:result>
</xsl:template>

<xsl:template match="in:SNPresult" mode="relate-variants">
   <xsl:variable name="variant-synonyms" select="tokenize(in:LabTest/in:variant_Synonyms/text(),'[,;]')"/>
   <xsl:variable name="primary-synonymL"  select="normalize-space($variant-synonyms[1])"/>
   <xsl:variable name="primary-synonym"   select="concat('variant_',translate($primary-synonymL,'>.:@','____'))"/>
   <xsl:for-each select="$variant-synonyms">
      <xsl:if test="position() gt 1">
         <xsl:variable name="secondary-synonymL"  select="normalize-space(.)"/>
         <xsl:variable name="secondary-synonym"  select="concat('variant_',translate($secondary-synonymL,'>.:@','____'))"/>
	 <rdf:Description>
	   <xsl:attribute name="rdf:about"><xsl:value-of select="$primary-synonym"/></xsl:attribute>
	   <skos:relatedMatch><xsl:attribute name="rdf:resource"><xsl:value-of select="$secondary-synonym"/></xsl:attribute></skos:relatedMatch>
	 </rdf:Description>
	 <rdf:Description>
	   <xsl:attribute name="rdf:about"><xsl:value-of select="$secondary-synonym"/></xsl:attribute>
	   <dct:identifier><xsl:value-of select="$secondary-synonymL"/></dct:identifier>
	 </rdf:Description>
      </xsl:if>
   </xsl:for-each>
</xsl:template>

<!-- Utility templates
-->

<xsl:template mode="date" match="*"><xsl:value-of select="text()"/><!-- ^^xsd:dateTime --></xsl:template>

</xsl:stylesheet>
