<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: Pat2rdf.xsl,v 1.23 2009/11/30 03:42:28 eric Exp $ -->
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:in="http://indivo.org/vocab/xml/documents#"
    xmlns="http://indivo.org/vocab/xml/documents#999"
    version="1.0">

<xsl:output method="text" indent='yes' encoding='utf-8'
	    omit-xml-declaration="yes"	    
	    media-type="text/turtle" version="1.0"/>

<xsl:template match="in:Envelope">
  @prefix : &lt;tag:eric@w3.org:2009/tmo/translator#&gt; .
  @prefix foaf: &lt;http://xmlns.com/foaf/0.1/&gt; .
  @prefix trans: &lt;tag:eric@w3.org:2009/tmo/translator#&gt; .  
  @prefix indivo: &lt;http://indivo.org/vocab/xml/documents#&gt; .
  @prefix xsd: &lt;http://www.w3.org/2001/XMLSchema#&gt; .
  @prefix cpr: &lt;http://purl.org/cpr/0.75#&gt; .
  @prefix rdfs: &lt;http://www.w3.org/2000/01/rdf-schema#&gt; .
  @prefix ro: &lt;http://www.obofoundry.org/ro/ro.owl#&gt; .
  @prefix skos: &lt;http://www.w3.org/2004/02/skos/core#&gt; .
  @prefix dct: &lt;http://purl.org/dc/terms/&gt; .
{
  &lt;&gt; a cpr:patient-record .
  _:patient cpr:subjectOfDescription &lt;&gt; .
<xsl:apply-templates select="in:CurrentStatus"/>
<xsl:apply-templates select="in:Encounter"/>
}
</xsl:template>

<xsl:template match="in:CurrentStatus">
  <xsl:apply-templates select="in:PatientID"/>
  <xsl:apply-templates select="in:Contact"/>
  <xsl:apply-templates select="in:PrimaryCarePhysician"/>
  <xsl:apply-templates select="in:Demographics"/>
  <xsl:apply-templates select="in:Prescriptions"/>
  <xsl:apply-templates select="in:Conditions"/>
  <!-- xsl:apply-templates select="in:Procedures"/ -->
  <!-- xsl:apply-templates select="in:Allergies"/ -->
  <!-- xsl:apply-templates select="in:Immunizations"/ -->
  <!-- xsl:apply-templates select="in:lifestyle"/ -->
  <!-- xsl:apply-templates select="in:familyHistory"/ -->
</xsl:template>

<xsl:template match="in:PatientID">
  _:patient cpr:patientID "<xsl:value-of select="."/>" .
</xsl:template>

<xsl:template match="in:Contact">
  <xsl:call-template name="contact">
    <xsl:with-param name="subject" select="'_:patient'"/>
    <xsl:with-param name="type" select="'cpr:patient'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="in:PrimaryCarePhysician">
  trans:PrimaryCarePhysician rdfs:subClassOf cpr:physician . # ont
  <xsl:call-template name="contact">
    <xsl:with-param name="subject" select="'_:pricare'"/>
    <xsl:with-param name="type" select="'trans:PrimaryCarePhysician'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="in:Demographics">
_:patient trans:demographics [
    indivo:dateOfBirth <xsl:apply-templates mode="date" select="in:dateOfBirth"/> ;
    indivo:gender "<xsl:value-of select="in:gender/text()"/>" ;
] .
</xsl:template>

<xsl:template name="contact">
  <xsl:param name="subject"/>
  <xsl:param name="type"/>
  <xsl:value-of select="$subject"/>  a <xsl:value-of select="$type"/> ;
  <xsl:apply-templates mode="contact"/>
  . 
</xsl:template>

<xsl:template mode="contact" match="in:name">
  <xsl:apply-templates mode="contact" select="*"/>
</xsl:template>

<xsl:template mode="contact" match="in:fullName">
  foaf:name "<xsl:value-of select="text()"/>" ;
</xsl:template>

<xsl:template mode="contact" match="in:givenName">
  foaf:givenName "<xsl:value-of select="text()"/>" ;
</xsl:template>

<xsl:template mode="contact" match="in:familyName">
  foaf:familyName "<xsl:value-of select="text()"/>" ;
</xsl:template>

<xsl:template mode="contact" match="in:email">
  foaf:mbox &lt;mailto:<xsl:value-of select="text()"/>&gt; ;
</xsl:template>

<xsl:template mode="contact" match="*">
</xsl:template>

<xsl:template match="in:Prescriptions">
  <xsl:apply-templates select="in:Prescription"/>
</xsl:template>

<xsl:template match="in:Prescription">
  [ a cpr:substance-administration ;
    trans:prescribedTo _:patient ;
    cpr:startsNoEarlierThan <xsl:apply-templates mode="date" select="in:medication/in:dateStarted"/> ; <!-- trans:dateStarted -->
<xsl:if test="in:medication/in:dateStopped"> 
    cpr:stopsNoEarlierThan <xsl:apply-templates mode="date" select="in:medication/in:dateStopped"/> ;
</xsl:if>
    ro:has_participant [
      a cpr:medication  ;
      trans:ndcCode &lt;http://indivo.org/codes/ndc/<xsl:value-of select="normalize-space(in:medication/in:name)"/>&gt; ;
      trans:genericName "<xsl:value-of select="in:medication/in:genericName"/>" ;    
    ] ;
  ] .
</xsl:template>

<xsl:template match="in:Conditions">
  <xsl:apply-templates select="in:Problem"/>
</xsl:template>

<xsl:template match="in:Problem">
  _:patient trans:hasCondition [<xsl:apply-templates mode="problem" select="*"/>
  ] .
<xsl:apply-templates mode="resources" select="in:name"/>
</xsl:template>

<xsl:template mode="problem" match="in:dateOnset">
  cpr:startsNoLaterThan <xsl:apply-templates mode="date" select="."/> ;
</xsl:template>

<xsl:template mode="problem" match="in:name">
   <xsl:variable name="problemL"  select="text()"/>
   <xsl:variable name="problem"   select="concat(':',lower-case(replace(replace(translate($problemL,' >.:@','_____'),$SQ2,''),$SQ,'')))"/>
  trans:diagnosedWith <xsl:value-of select="$problem"/> ;
  trans:ICD9 "<xsl:value-of select="@value"/>" ;
</xsl:template>

<xsl:template mode="resources" match="in:name">
   <xsl:variable name="problemL"  select="text()"/>
   <xsl:variable name="problem"   select="concat(':',lower-case(replace(replace(translate($problemL,' >.:@','_____'),$SQ2,''),$SQ,'')))"/>
   <xsl:value-of select="concat($NL,$problem,' dct:identifier ',$DQ,$problemL,$DQ,' .',$NL)"/>
</xsl:template>

<xsl:template mode="problem" match="*">
  # unmatched <xsl:value-of select="name()"/>
</xsl:template>

<xsl:template match="in:Encounter">
  [ a trans:Encounter ;
    trans:patient _:patient ;
    trans:dateOfEncounter <xsl:apply-templates mode="date" select="in:Date"/> ;
<xsl:apply-templates select="in:WorkingDiagnosis/in:PreliminaryDiagnosis"/>
    trans:reportedSymptoms "<xsl:value-of select="in:ReportedSymptoms/text()"/>" ;
<xsl:apply-templates select="in:LabTests/in:Test"/>    
  ] .
<xsl:apply-templates select="*//in:SNPresult" mode="relate-variants"/>    
</xsl:template>

<xsl:template match="in:PreliminaryDiagnosis">
    trans:workingDiagnosis "<xsl:value-of select="in:DiagnosisDescription/text()"/>" ;
</xsl:template>

<xsl:template match="in:Test">
    trans:test [
        # indivo:dateMeasured <xsl:apply-templates mode="date" select="in:dateMeasured"/> ;
        trans:testName "<xsl:value-of select="in:name/text()"/>" ;
        <xsl:apply-templates select="in:result"/><xsl:apply-templates select="in:SNPresult"/>
    ] ;
</xsl:template>

<xsl:template match="in:Test[in:SNPresult]">
    trans:test [
        # indivo:dateMeasured <xsl:apply-templates mode="date" select="in:dateMeasured"/> ;
        a :<xsl:value-of select="replace(replace(in:name/text(),' ','_'),$SQ,'')"/> ;
        <xsl:apply-templates select="in:result"/><xsl:apply-templates select="in:SNPresult"/>
    ] ;
</xsl:template>
<xsl:variable name="SQ">
<xsl:text>'</xsl:text>
</xsl:variable>
<xsl:variable name="SQ2">
<xsl:text>’</xsl:text>
</xsl:variable>
<xsl:variable name="DQ">
<xsl:text>"</xsl:text>
</xsl:variable>
<xsl:variable name="NL">
<xsl:text>
</xsl:text>
</xsl:variable>

<xsl:template match="in:result">
    # @@not done ;
</xsl:template>

<!-- Replaced by lebot Jan 2011 
xsl:template match="in:SNPresult">
       trans:result [
           trans:variant_Synonyms "<xsl:value-of select="in:LabTest/in:variant_Synonyms/text()"/>" ;
       ] ;
</xsl:template-->

<xsl:template match="in:SNPresult">
   <xsl:variable name="variant-synonyms" select="tokenize(in:LabTest/in:variant_Synonyms/text(),'[,;]')"/>
   <xsl:variable name="primary-synonymL"  select="normalize-space($variant-synonyms[1])"/>
   <xsl:variable name="primary-synonym"   select="concat('variant_',translate($primary-synonymL,'>.:@','____'))"/>
       trans:result [
           a :SNPResult ;
           trans:feature :<xsl:value-of select="$primary-synonym"/> ;
           trans:present true ;
       ] ;
</xsl:template>

<xsl:template match="in:SNPresult" mode="relate-variants">
   <xsl:variable name="variant-synonyms" select="tokenize(in:LabTest/in:variant_Synonyms/text(),'[,;]')"/>
   <xsl:variable name="primary-synonymL"  select="normalize-space($variant-synonyms[1])"/>
   <xsl:variable name="primary-synonym"   select="concat(':variant_',translate($primary-synonymL,'>.:@','____'))"/>
   <xsl:for-each select="$variant-synonyms">
      <xsl:if test="position() gt 1">
         <xsl:variable name="secondary-synonymL"  select="normalize-space(.)"/>
         <xsl:variable name="secondary-synonym"  select="concat(':variant_',translate($secondary-synonymL,'>.:@','____'))"/>
         <xsl:value-of select="concat($primary-synonym,  ' skos:relatedMatch ',$secondary-synonym,' .',$NL)"/>
         <xsl:value-of select="concat($secondary-synonym,' dct:identifier ',$DQ,$secondary-synonymL,$DQ,' .',$NL)"/>
      </xsl:if>
   </xsl:for-each>
</xsl:template>

<!-- Utility templates
-->

<xsl:template mode="date" match="*">"<xsl:value-of select="text()"/>"<!-- ^^xsd:dateTime --></xsl:template>

</xsl:stylesheet>
