<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: Pat2rdf.xsl,v 1.23 2009/11/30 03:42:28 eric Exp $ -->
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns="http://indivo.org/vocab/xml/documents#"
		xmlns:grddl="http://www.w3.org/2003/g/data-view#"
		>

<xsl:output method="xml" indent='yes' encoding='utf-8'
omit-xml-declaration="no"	    
media-type="application/indivo+xml" version="1.0"/>

<xsl:template match="/root">
  <xsl:comment> -*- mode: nxml; tab-width: 8; -*- </xsl:comment><xsl:processing-instruction name="xml-stylesheet"><xsl:text>type="text/xsl" href="Patrdf2html.xsl"</xsl:text></xsl:processing-instruction>
  <Envelope grddl:transformation="http://dvcs.w3.org/hg/TMO-Indivo/raw-file/tip/syntheticPatients/Indivo2RDFXML.xsl">
    <CurrentStatus>
      <xsl:apply-templates mode="copyToDefaultNS" select="PatientID"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="Contact"/>
      <xsl:apply-templates select="Practice"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="Demographics"/>
      <xsl:apply-templates select="prescriptions"/>
      <xsl:apply-templates select="conditions"/>
      <xsl:apply-templates select="procedures"/>
      <xsl:apply-templates select="allergies"/>
      <xsl:apply-templates select="immunizations"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="lifestyle"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="familyHistory"/>
    </CurrentStatus>
    <xsl:apply-templates select="Encounter"/>
  </Envelope>
</xsl:template>

<xsl:template match="Practice">
  <PrimaryCarePhysician>
    <name>
      <xsl:apply-templates mode="copyToDefaultNS" select="primaryCarePhysician/fullName"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="primaryCarePhysician/givenName"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="primaryCarePhysician/familyName"/>
    </name>
    <address>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/streetAddress"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/postalCode"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/locality"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/region"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/country"/>
      <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/timeZone"/>
    </address>
    <xsl:apply-templates mode="copyToDefaultNS" select="practiceAddress/phoneNumber"/>
  </PrimaryCarePhysician>
</xsl:template>

<xsl:template match="prescriptions">
  <Prescriptions>
    <xsl:for-each select="drug">
      <Prescription>
	<medication>
	  <dateStarted><xsl:value-of select="datePrescribed"/></dateStarted>
	  <xsl:if test="datePrescriptionEnded != 'false'">
	    <dateStopped><xsl:value-of select="datePrescriptionEnded"/></dateStopped>
	  </xsl:if>
	  <name>
	    <xsl:attribute name="type">http://indivo.org/codes/ndc</xsl:attribute>
	    <xsl:value-of select="NDC"/>
	  </name>
	  <genericName><xsl:value-of select="genericName"/></genericName>
	  <!-- brandName></brandName -->
	  <dose>
	    <value><xsl:value-of select="999"/></value>
	    <unit type="http://indivo.org/codes/units#">
	      <xsl:attribute name="value">
		<xsl:value-of select="999"/>
	      </xsl:attribute>
	    </unit>
	  </dose>
	  <strength>
	    <value><xsl:value-of select="strength"/></value>
	    <unit type="http://indivo.org/codes/units#">
	      <xsl:attribute name="value">
		<xsl:value-of select="unit"/>
	      </xsl:attribute>
	    </unit>
	  </strength>
	  <xsl:apply-templates mode="copyToDefaultNS" select="frequency"/>
	</medication>
	<prescribedBy>
	  <name><xsl:value-of select="prescribedBy"/></name>
	  <institution><xsl:value-of select="/root/Practice/practiceName"/></institution>
	</prescribedBy>
	<dispenseAsWritten>true</dispenseAsWritten>
	<refillInfo><xsl:value-of select="refill"/></refillInfo>
	<instructions><xsl:value-of select="physicianNotes"/></instructions>
      </Prescription>
    </xsl:for-each>
  </Prescriptions>
</xsl:template>

<xsl:template match="conditions">
  <Conditions>
    <xsl:for-each select="condition">
      <Problem>
	<dateOnset><xsl:value-of select="dateDiagnosed"/>T12:00:00</dateOnset> <!-- dateOnset should be different that dateDiagnosed -->
	<!-- <dateResolution></dateResolution> -->
	<name type="http://indivo.org/codes/ICD9">
	  <xsl:attribute name="value">
	    <xsl:value-of select="ICD9"/>
	  </xsl:attribute>
	  <xsl:value-of select="diagnosedWith"/>
	</name>
	<comments><xsl:value-of select="physicianNotes"/></comments>
	<xsl:apply-templates mode="copyToDefaultNS" select="diagnosedBy"/>
      </Problem>
    </xsl:for-each>
  </Conditions>
</xsl:template>

<xsl:template match="procedures">
  <Procedures>
    <xsl:for-each select="procedure">
      <Procedure>
	<datePerformed><xsl:value-of select="procedureDate"/>T12:00:00</datePerformed>
	<name type="http://indivo.org/codes/ICD9_Procedure">
	  <xsl:attribute name="value">
	    <xsl:value-of select="ICD9_Procedure"/>
	  </xsl:attribute>
	  <xsl:value-of select="procedureName"/>
	</name>
	<Provider>
	  <name><xsl:value-of select="referredBy"/></name>
	  <institution><xsl:value-of select="referredInstitution"/></institution>
	</Provider>
	<comments><xsl:value-of select="procedureNotes"/></comments>
      </Procedure>
    </xsl:for-each>
  </Procedures>
</xsl:template>

<xsl:template match="allergies">
  <Allergies>
    <xsl:for-each select="child::*">
      <Allergy>
	<allergen>
	  <type type="http://codes.indivo.org/codes/allergentypes/"><xsl:value-of select="name(.)"/></type>
	  <name type="http://codes.indivo.org/codes/allergens/"><xsl:value-of select="."/></name>
	</allergen>
      </Allergy>
    </xsl:for-each>
  </Allergies>
</xsl:template>

<xsl:template match="immunizations">
  <Immunizations>
    <xsl:for-each select="child::*">
      <Immunization>
	<dateAdministered><xsl:value-of select="date"/>-01-01T00:00:00</dateAdministered>
	<xsl:apply-templates mode="copyToDefaultNS" select="administeredBy"/>
	<vaccine>
	  <type><xsl:value-of select="name(.)"/></type>
	  <manufacturer></manufacturer>
	  <lot></lot>
	  <expiration></expiration>
	</vaccine>
	<sequence><xsl:value-of select="stage"/></sequence>
	<anatomicSurface><xsl:value-of select="method"/></anatomicSurface> <!-- Not exactly.. -->
	<adverseEvent></adverseEvent>
      </Immunization>
    </xsl:for-each>
  </Immunizations>
</xsl:template>

<xsl:template match="Encounter">
  <Encounter>
    <xsl:apply-templates select="dateOfEncounter"/>
    <xsl:apply-templates select="physician"/>
    <xsl:apply-templates select="medicalBaseline"/>
    <xsl:apply-templates select="medicalTest"/>
    <xsl:apply-templates select="reportedSymptoms"/>
    <xsl:apply-templates select="workingDiagnosis"/>
    <LabTests>
      <xsl:apply-templates select="test">
	<xsl:with-param name="date" select="dateOfEncounter/text()"/>
      </xsl:apply-templates>
    </LabTests>

    <!-- xsl:for-each select="child::*">
      <Immunization>
	<dateAdministered><xsl:value-of select="date"/>-01-01T12:00:00</dateAdministered>
	<xsl:apply-templates mode="copyToDefaultNS" select="administeredBy"/>
	<vaccine>
	  <type><xsl:value-of select="name(.)"/></type>
	  <manufacturer></manufacturer>
	  <lot></lot>
	  <expiration></expiration>
	</vaccine>
	<sequence><xsl:value-of select="stage"/></sequence>
	<anatomicSurface><xsl:value-of select="method"/></anatomicSurface>
	<adverseEvent></adverseEvent>
      </Immunization>
    </xsl:for-each -->
  </Encounter>
</xsl:template>

<xsl:template match="dateOfEncounter">
  <Date>
    <xsl:value-of select="text()"/>
  </Date>
</xsl:template>

<xsl:template match="physician">
  <Contact>
    <fullName>
      <xsl:value-of select="text()"/>
    </fullName>
  </Contact>
</xsl:template>

<xsl:template match="medicalBaseline">
  <MedicalBaseline>
    <xsl:value-of select="text()"/>
  </MedicalBaseline>
</xsl:template>

<xsl:template match="medicalTest">
  <MedicalTest>
    <xsl:value-of select="text()"/>
  </MedicalTest>
</xsl:template>

<xsl:template match="reportedSymptoms">
  <ReportedSymptoms>
    <xsl:value-of select="text()"/>
  </ReportedSymptoms>
</xsl:template>

<xsl:template match="workingDiagnosis">
  <WorkingDiagnosis>
    <xsl:choose>
      <xsl:when test="preliminaryDiagnosis">
	<PreliminaryDiagnosis>
	  <xsl:apply-templates mode="diagnosis" select="preliminaryDiagnosis"/>
	</PreliminaryDiagnosis>
	<xsl:if test="differentialDiagnosis">
	  <DifferentialDiagnosis>
	    <xsl:apply-templates mode="diagnosis" select="differentialDiagnosis"/>
	  </DifferentialDiagnosis>
	</xsl:if>
      </xsl:when>
      <xsl:otherwise>
	<PreliminaryDiagnosis>
	  <DiagnosisDescription>
	    <xsl:value-of select="text()"/>
	  </DiagnosisDescription>
	</PreliminaryDiagnosis>
      </xsl:otherwise>
    </xsl:choose>    
  </WorkingDiagnosis>
</xsl:template>

<xsl:template mode="diagnosis" match="diagnosisDescription">
  <DiagnosisDescription><xsl:value-of select="text()"/></DiagnosisDescription>
</xsl:template>

<xsl:template mode="diagnosis" match="ICD9">
  <ICD9><xsl:value-of select="text()"/></ICD9>
</xsl:template>

<xsl:template mode="diagnosis" match="ICD9Description">
  <ICD9Description><xsl:value-of select="text()"/></ICD9Description>
</xsl:template>

<xsl:template match='test'>
  <xsl:param name="date"/>
  <Test>
    <dateMeasured><xsl:value-of select="$date"/></dateMeasured>
    <name><xsl:value-of select="testName"/></name>
    <xsl:choose>
      <xsl:when test='@x_2="Genotyping SNPs"'>
	<xsl:apply-templates mode="SNP" select="result"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="result"/>
      </xsl:otherwise>
    </xsl:choose>
    <status>@@@</status>
  </Test>
</xsl:template>

<xsl:template mode="SNP" match="result">
  <SNPresult>
  <LabTest>
    <variant_Synonyms><xsl:value-of select="variant_Synonyms/text()"/></variant_Synonyms>
  </LabTest>
  </SNPresult>
</xsl:template>

<xsl:template match="result">
  <HCLSresult>
  <LabTest>
    <variant_Synonyms><xsl:value-of select="variant_Synonyms/text()"/></variant_Synonyms>
  </LabTest>
  </HCLSresult>
</xsl:template>

<!-- Utility functions -->
<xsl:template mode="copyToDefaultNS" match="*">
  <xsl:element name="{local-name()}">
    <xsl:apply-templates mode="copyToDefaultNS" select="@*"/>
    <xsl:apply-templates mode="copyToDefaultNS"/>
  </xsl:element>
</xsl:template>

<xsl:template mode="copyToDefaultNS" match="@*">
  <xsl:attribute name="{local-name()}">
    <xsl:value-of select="." />
  </xsl:attribute>
</xsl:template>


</xsl:stylesheet>
